@@ -22,16 +22,17 @@ from astx.base import (
     OperatorType,
     SourceLocation,
     StatementType,
+    Undefined,
 )
 from astx.blocks import (
     Block,
     Module,
 )
 from astx.callables import (
-    Call,
     Function,
+    FunctionCall,
     FunctionPrototype,
-    Return,
+    FunctionReturn,
 )
 from astx.datatypes import (
     Boolean,
@@ -43,10 +44,13 @@ from astx.datatypes import (
     Int8,
     Int16,
     Int32,
-    Int32Literal,
     Int64,
     Integer,
     Literal,
+    LiteralInt8,
+    LiteralInt16,
+    LiteralInt32,
+    LiteralInt64,
     Number,
     SignedInteger,
 )
@@ -59,6 +63,7 @@ from astx.mixes import (
     NamedExpr,
 )
 from astx.modifiers import (
+    MutabilityKind,
     ScopeKind,
     VisibilityKind,
 )
@@ -67,8 +72,11 @@ from astx.operators import (
     UnaryOp,
 )
 from astx.variables import (
-    VarDecl,
+    Argument,
+    InlineVariableDeclaration,
     Variable,
+    VariableAssignment,
+    VariableDeclaration,
 )
 
 
@@ -77,60 +85,68 @@ def get_version() -> str:
     try:
         return importlib_metadata.version(__name__)
     except importlib_metadata.PackageNotFoundError:  # pragma: no cover
-        return "0.7.0"  # semantic-release
+        return "0.9.1"  # semantic-release
 
 
 __all__ = [
+    "Argument",
     "AST",
     "ASTKind",
+    "base",
+    "BinaryOp",
+    "Block",
+    "blocks",
+    "Boolean",
+    "callables",
     "DataType",
+    "DataTypeOps",
+    "datatypes",
     "Expr",
     "ExprType",
-    "OperatorType",
-    "SourceLocation",
-    "StatementType",
-    "Call",
-    "Function",
-    "FunctionPrototype",
-    "Return",
-    "Boolean",
-    "DataTypeOps",
     "Float16",
     "Float32",
     "Float64",
     "Floating",
-    "Int8",
-    "Int16",
-    "Int32",
-    "Int32Literal",
-    "Int64",
-    "Integer",
-    "Literal",
-    "Number",
-    "SignedInteger",
+    "flows",
     "ForCountLoop",
     "ForRangeLoop",
-    "If",
-    "NamedExpr",
-    "ScopeKind",
-    "VisibilityKind",
-    "BinaryOp",
-    "UnaryOp",
-    "VarDecl",
-    "Variable",
-    "Block",
-    "Module",
-    "Target",
-    "base",
-    "blocks",
-    "callables",
-    "datatypes",
-    "flows",
-    "mixes",
-    "operators",
-    "symbol_table",
-    "variables",
+    "Function",
+    "FunctionCall",
+    "FunctionPrototype",
+    "FunctionReturn",
     "get_version",
+    "If",
+    "InlineVariableDeclaration",
+    "Int16",
+    "Int32",
+    "Int64",
+    "Int8",
+    "Integer",
+    "Literal",
+    "LiteralInt16",
+    "LiteralInt32",
+    "LiteralInt64",
+    "LiteralInt8",
+    "mixes",
+    "Module",
+    "MutabilityKind",
+    "NamedExpr",
+    "Number",
+    "operators",
+    "OperatorType",
+    "ScopeKind",
+    "SignedInteger",
+    "SourceLocation",
+    "StatementType",
+    "symbol_table",
+    "Target",
+    "UnaryOp",
+    "Undefined",
+    "VariableAssignment",
+    "VariableDeclaration",
+    "Variable",
+    "variables",
+    "VisibilityKind",
 ]
 
 
